==> openshift-model-installer-5.12.0-sources.jar: io/fabric8/openshift/api/model/installer/v1/MachinePoolPlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachinePoolPlatformBuilder extends io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluentImpl<io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform,io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformBuilder>{
  public MachinePoolPlatformBuilder() {
    this(false);
  }
  public MachinePoolPlatformBuilder(java.lang.Boolean validationEnabled) {
    this(new MachinePoolPlatform(), validationEnabled);
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachinePoolPlatform(), validationEnabled);
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluent<?> fluent,io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform instance) {
    this(fluent, instance, false);
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluent<?> fluent,io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlibabacloud(instance.getAlibabacloud()); 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withBaremetal(instance.getBaremetal()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withIbmcloud(instance.getIbmcloud()); 
    fluent.withLibvirt(instance.getLibvirt()); 
    fluent.withOpenstack(instance.getOpenstack()); 
    fluent.withOvirt(instance.getOvirt()); 
    fluent.withVsphere(instance.getVsphere()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform instance) {
    this(instance,false);
  }
  public MachinePoolPlatformBuilder(io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlibabacloud(instance.getAlibabacloud()); 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withBaremetal(instance.getBaremetal()); 
    this.withGcp(instance.getGcp()); 
    this.withIbmcloud(instance.getIbmcloud()); 
    this.withLibvirt(instance.getLibvirt()); 
    this.withOpenstack(instance.getOpenstack()); 
    this.withOvirt(instance.getOvirt()); 
    this.withVsphere(instance.getVsphere()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatformFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.v1.MachinePoolPlatform build() {
    MachinePoolPlatform buildable = new MachinePoolPlatform(fluent.getAlibabacloud(),fluent.getAws(),fluent.getAzure(),fluent.getBaremetal(),fluent.getGcp(),fluent.getIbmcloud(),fluent.getLibvirt(),fluent.getOpenstack(),fluent.getOvirt(),fluent.getVsphere());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachinePoolPlatformBuilder that = (MachinePoolPlatformBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.2.0-sources.jar: io/fabric8/openshift/api/model/installer/v1/MachinePoolPlatformBuilder.java <==
package io.fabric8.openshift.api.model.installer.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolPlatformBuilder extends MachinePoolPlatformFluentImpl<MachinePoolPlatformBuilder> implements VisitableBuilder<MachinePoolPlatform,MachinePoolPlatformBuilder>{
  public MachinePoolPlatformBuilder() {
    this(false);
  }
  public MachinePoolPlatformBuilder(Boolean validationEnabled) {
    this(new MachinePoolPlatform(), validationEnabled);
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatformFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatformFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePoolPlatform(), validationEnabled);
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatformFluent<?> fluent,MachinePoolPlatform instance) {
    this(fluent, instance, false);
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatformFluent<?> fluent,MachinePoolPlatform instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlibabacloud(instance.getAlibabacloud()); 
    fluent.withAws(instance.getAws()); 
    fluent.withAzure(instance.getAzure()); 
    fluent.withBaremetal(instance.getBaremetal()); 
    fluent.withGcp(instance.getGcp()); 
    fluent.withIbmcloud(instance.getIbmcloud()); 
    fluent.withLibvirt(instance.getLibvirt()); 
    fluent.withOpenstack(instance.getOpenstack()); 
    fluent.withOvirt(instance.getOvirt()); 
    fluent.withVsphere(instance.getVsphere()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatform instance) {
    this(instance,false);
  }
  public MachinePoolPlatformBuilder(MachinePoolPlatform instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlibabacloud(instance.getAlibabacloud()); 
    this.withAws(instance.getAws()); 
    this.withAzure(instance.getAzure()); 
    this.withBaremetal(instance.getBaremetal()); 
    this.withGcp(instance.getGcp()); 
    this.withIbmcloud(instance.getIbmcloud()); 
    this.withLibvirt(instance.getLibvirt()); 
    this.withOpenstack(instance.getOpenstack()); 
    this.withOvirt(instance.getOvirt()); 
    this.withVsphere(instance.getVsphere()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachinePoolPlatformFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePoolPlatform build() {
    MachinePoolPlatform buildable = new MachinePoolPlatform(fluent.getAlibabacloud(),fluent.getAws(),fluent.getAzure(),fluent.getBaremetal(),fluent.getGcp(),fluent.getIbmcloud(),fluent.getLibvirt(),fluent.getOpenstack(),fluent.getOvirt(),fluent.getVsphere());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
